@@ -25,7 +25,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: ai.lua 8935 2007-06-24 20:18:51Z gruiick $
 --
 
 -- The list of registered AIs in BOS
@@ -55,13 +54,13 @@ DefineAiHelper(
   {"build", "unit-engineer",
    "unit-msilo", "unit-aircraftfactory", "unit-magmapump", "unit-camp",
    "unit-powerplant", "unit-hosp", "unit-vfac", "unit-vault", "unit-gturret",
-   "unit-cam", "unit-cannon", "unit-nuke", "unit-radar"},
+   "unit-cam", "unit-cannon", "unit-nukepowerplant", "unit-radar"},
   --
   -- Building can train which units.
   --
   {"train", "unit-vault", "unit-engineer"},
-  {"train", "unit-camp", "unit-assault", "unit-bazoo", "unit-grenadier",
-   "unit-dorcoz"},
+  {"train", "unit-camp", "unit-engineer", "unit-assault", "unit-bazoo",
+   "unit-grenadier", "unit-dorcoz"},
   {"train", "unit-hosp", "unit-medic"},
   {"train", "unit-vfac", "unit-apcs", "unit-harvester", "unit-artil",
    "unit-buggy", "unit-rtank", "unit-tank"},
@@ -72,7 +71,7 @@ DefineAiHelper(
   {"repair", "unit-engineer",
    "unit-msilo", "unit-aircraftfactory", "unit-magmapump", "unit-camp", "unit-apcs",
    "unit-powerplant", "unit-hosp", "unit-vfac", "unit-vault", "unit-gturret",
-   "unit-nuke", "unit-radar"},
+   "unit-nukepowerplant", "unit-radar"},
   --
   -- Reduce unit limits.
   --
