@@ -9,7 +9,7 @@
 --
 --      guichan.lua - The main UI lua script.
 --
---      (c) Copyright 2005-2007 by François Beerten
+--      (c) Copyright 2005-2008 by François Beerten
 --
 --      This program is free software; you can redistribute it and/or modify
 --      it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 --      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 --      02111-1307, USA.
 --
---      $Id: guichan.lua 9066 2007-08-25 13:28:13Z feb $
 
 -- Global useful objects for menus  ----------
 dark = Color(38, 38, 78, 128)
@@ -101,9 +100,8 @@ function AddMenuHelpers(menu)
     return self:addLabel(text, x, y, Fonts["large"], false)
   end
 
-  function menu:addButton(caption, hotkey, x, y, callback, size)
+  function menu:addButton(caption, x, y, callback, size)
     local b = ButtonWidget(caption)
-    b:setHotKey(hotkey)
     b:setActionCallback(callback)
     if (size == nil) then size = {200, 24} end
     b:setSize(size[1], size[2])
@@ -114,8 +112,8 @@ function AddMenuHelpers(menu)
     return b
   end
 
-  function menu:addSmallButton(caption, hotkey, x, y, callback)
-    return self:addButton(caption, hotkey, x, y, callback, {106, 28})
+  function menu:addSmallButton(caption, x, y, callback)
+    return self:addButton(caption, x, y, callback, {106, 28})
   end
 
   function menu:addSlider(min, max, w, h, x, y, callback)
@@ -217,22 +215,26 @@ function AddMenuHelpers(menu)
 
   function menu:addMapBrowser(path, x, y, w, h, default)
     local function listFilesAndDirs(path)
-        local dirlist = {}
-        local dirs = ListDirsInDirectory(path)
-        for i,f in ipairs(dirs) do
-          if (string.find(f, "^%w.*%.map$")) then
-            table.insert(dirlist, f)
-          else
-            if (string.find(f, "^%a")) then
-              table.insert(dirlist, f .. "/")
-            end
-          end
+      local dirlist = {}
+      local filelist = {}
+      local dirs = ListDirsInDirectory(path)
+      -- Create table of dirs and files
+      for i,f in ipairs(dirs) do
+        if (string.find(f, "^%w.*%.map$")) then
+          table.insert(filelist, f)
+        elseif (string.find(f, "^%a")) then
+          table.insert(dirlist, f .. "/")
         end
-        return dirlist
+      end
+      -- Append files after dirs
+      for i,f in ipairs(filelist) do
+        table.insert(dirlist, f)
+      end
+      return dirlist
     end
     local browser = self:addBrowser(path, listFilesAndDirs, x, y, w, h, default)
     local function getMap(browser)
-       return browser:getSelectedItem() .. "/presentation.smp"
+      return browser.path .. browser:getSelectedItem() .. "/presentation.smp"
     end
     browser.getSelectedMap = getMap
     return browser
@@ -342,6 +344,10 @@ function RunResultsMenu()
     return
   end
 
+  if (Cheater) then
+    result = result .. " - " .. _("Cheater")
+  end
+
   menu = BosMenu(_("Results"), background)
   menu:writeLargeText(result, sx*6, sy*5)
 
@@ -361,7 +367,7 @@ function RunResultsMenu()
     end
   end
 
-  menu:addButton(_("~!Continue"), "c", Video.Width / 2 - 100, Video.Height - 100,
+  menu:addButton(_("~!Continue"), Video.Width / 2 - 100, Video.Height - 100,
                  function() menu:stop() end)
 
   menu:run()
@@ -432,9 +438,11 @@ function GameStarting()
     end
   end
 
+  Cheater = false
+
   -- FIXME: get the version from somewhere else
-  UI.StatusLine:Set("Bos Wars V" .. "2.4.0" ..
-    ", (c) 1998-2007 by the Bos Wars and Stratagus Project.")
+  UI.StatusLine:Set("Bos Wars V" .. "2.5.0" ..
+    ", (c) 1998-2008 by the Bos Wars and Stratagus Project.")
 end
 
 
@@ -499,7 +507,7 @@ function RunStartGameMenu(s)
     numplayers = nplayers
     players:setCaption(""..nplayers)
     descr:setCaption(description)
-	mapsize:setCaption(""..h.."x"..w)
+	mapsize:setCaption(""..w.."x"..h)
     OldPresentMap(description, nplayers, w, h, id)
   end
  
@@ -508,7 +516,7 @@ function RunStartGameMenu(s)
                                      "maps/"..selectedmap)
   local function cb(s)
     maptext:setCaption(browser:getSelectedItem())
-    Load("maps/" .. browser:getSelectedMap())
+    Load(browser:getSelectedMap())
     selectedmap = browser:getSelectedItem()
   end
   browser:setActionCallback(cb)
@@ -516,14 +524,14 @@ function RunStartGameMenu(s)
   AllowAllUnits()
   local function startgamebutton(s)
     print("Starting map -------")
-    RunMap("maps/" .. browser:getSelectedMap(), nil, fow:isMarked(),
+    RunMap(browser:getSelectedMap(), nil, fow:isMarked(),
            revealmap:isMarked())
     PresentMap = OldPresentMap
     menu:stop()
   end
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
-  menu:addButton(_("~!Start"), "s", Video.Width / 2 + 50 ,  Video.Height - 100,
+  menu:addButton(_("~!Start"), Video.Width / 2 + 50 ,  Video.Height - 100,
                  startgamebutton)
 
   menu:run()
@@ -553,9 +561,9 @@ function RunReplayMenu(s)
     menu:stop()
   end
 
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
-  menu:addButton(_("~!Start"), "s", Video.Width / 2 + 50 ,  Video.Height - 100,
+  menu:addButton(_("~!Start"), Video.Width / 2 + 50 ,  Video.Height - 100,
                  startreplaybutton)
 
   menu:run()
@@ -597,9 +605,9 @@ function RunLoadGameMenu(s)
       end
     menu:stop()
   end
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
-  menu:addButton(_("~!Start"), "s", Video.Width / 2 + 50 ,  Video.Height - 100,
+  menu:addButton(_("~!Start"), Video.Width / 2 + 50 ,  Video.Height - 100,
                  startgamebutton)
 
   DisallowAllUnits()
@@ -612,12 +620,12 @@ function RunEditorMenu(s)
 
   menu = BosMenu(_("Editor"))
 
-  menu:addButton(_("Create ~!New Map"), "n", x, 260,
+  menu:addButton(_("Create ~!New Map"), x, 260,
     function() RunEditorNewMenu(); menu:stop() end)
-  menu:addButton(_("~!Load Map"), "l", x, 300,
+  menu:addButton(_("~!Load Map"), x, 300,
     function() RunEditorLoadMenu(); menu:stop() end)
 
-  menu:addButton(_("~!Cancel"), "c", x, Video.Height - 100,
+  menu:addButton(_("~!Cancel"), x, Video.Height - 100,
     function() menu:stop() end)
 
   menu:run()
@@ -665,9 +673,9 @@ function RunEditorNewMenu()
   ysize = menu:addTextInputField(tostring(defaultSize[2]),
     Video.Width / 2 + 10 + 60, 8 * sy, 40)
 
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
     function() menu:stop() end)
-  menu:addButton(_("Start ~!Editor"), "e", Video.Width / 2 + 50, Video.Height - 100,
+  menu:addButton(_("Start ~!Editor"), Video.Width / 2 + 50, Video.Height - 100,
     starteditorbutton)
 
   menu:run()
@@ -706,7 +714,7 @@ function RunEditorLoadMenu()
                                      "maps/"..selectedmap)
   local function selectMap(s)
     maptext:setCaption(browser:getSelectedItem())
-    Load("maps/" .. browser:getSelectedMap())
+    Load(browser:getSelectedMap())
     selectedmap = browser:getSelectedItem()
   end
   browser:setActionCallback(selectMap)
@@ -717,9 +725,9 @@ function RunEditorLoadMenu()
     HandleCommandKey = HandleIngameCommandKey
     menu:stop()
   end
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
-  menu:addButton(_("Start ~!Editor"), "e", Video.Width / 2 + 50, Video.Height -100,
+  menu:addButton(_("Start ~!Editor"), Video.Width / 2 + 50, Video.Height -100,
                  starteditorbutton)
 
   menu:run()
@@ -739,22 +747,22 @@ function BuildMainMenu(menu)
   local x1 = x - 100
   local x2 = 2*x - 100
 
-  menu:addButton(_("~!Start Game"), "s", x1, ystep * 2, RunStartGameMenu)
-  menu:addButton(_("~!Load Game"), "l", x1, ystep * 3, RunLoadGameMenu)
-  menu:addButton(_("~!Campaigns"), "c", x2, ystep * 2, RunCampaignsMenu)
-  menu:addButton(_("Show ~!Replay"), "r", x2, ystep * 3, RunReplayMenu)
+  menu:addButton(_("~!Start Game"), x1, ystep * 2, RunStartGameMenu)
+  menu:addButton(_("~!Load Game"), x1, ystep * 3, RunLoadGameMenu)
+  menu:addButton(_("~!Campaigns"), x2, ystep * 2, RunCampaignsMenu)
+  menu:addButton(_("Show ~!Replay"), x2, ystep * 3, RunReplayMenu)
 
-  menu:addButton(_("~!MultiPlayer"), "m", x1, ystep * 5, RunMultiPlayerMenu)
-  menu:addButton(_("~!Options"), "o", x2, ystep * 5, function() RunOptionsMenu() menu:stop(1) end)
+  menu:addButton(_("~!MultiPlayer"), x1, ystep * 5, RunMultiPlayerMenu)
+  menu:addButton(_("~!Options"), x2, ystep * 5, function() RunOptionsMenu() menu:stop(1) end)
 
-  menu:addButton(_("Cre~!dits"), "d", x1, ystep * 6, RunCreditsMenu)
-  menu:addButton(_("Start ~!Editor"), "e", x2, ystep * 6, RunEditorMenu)
+  menu:addButton(_("Cre~!dits"), x1, ystep * 6, RunCreditsMenu)
+  menu:addButton(_("Start ~!Editor"), x2, ystep * 6, RunEditorMenu)
 
-  menu:addButton(_("E~!xit"), "x", Video.Width / 2 - 100, Video.Height - 100,
+  menu:addButton(_("E~!xit"), Video.Width / 2 - 100, Video.Height - 100,
                  function() menu:stop() end)
 
   if false then 
-     menu:addButton("~!Widgets Demo", "w", x2, ystep * 7, RunWidgetsMenu)
+     menu:addButton("~!Widgets Demo", x2, ystep * 7, RunWidgetsMenu)
   end
 end
 
@@ -769,6 +777,14 @@ function RunMainMenu(s)
   end
 end
 
+function RunMapFromCommandLine()
+  ResetMapOptions()
+  AllowAllUnits()
+  if (CliMapName ~= "") then
+    RunMap(CliMapName, nil, true, false)
+  end
+end
 
+RunMapFromCommandLine()
 RunMainMenu()
 
