@@ -25,7 +25,6 @@
 --      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 --      02111-1307, USA.
 --
---      $Id: campaigns.lua 9073 2007-08-26 03:00:47Z jim4 $
 
 
 function RunBriefingMenu(objectivestext, briefingtext, briefingsound)
@@ -55,7 +54,7 @@ function RunBriefingMenu(objectivestext, briefingtext, briefingsound)
   t:setBackgroundColor(dark)
   menu:add(t, Video.Width / 2 - 200, Video.Height / 20 * 3)
 
-  menu:addButton(_("~!Start"), "s", Video.Width / 2 - 100, Video.Height - 100,
+  menu:addButton(_("~!Start"), Video.Width / 2 - 100, Video.Height - 100,
     function()
       if (channel ~= nil) then StopChannel(channel) end
       menu:stop()
@@ -139,9 +138,9 @@ function RunCampaignsMenu(s)
     RunCampaign("campaigns/" .. browser:getSelectedItem() .. "/campaign.lua")
     menu:stop()
   end
-  menu:addButton(_("~!Main Menu"), "m", Video.Width / 2 - 250, Video.Height - 100,
+  menu:addButton(_("~!Main Menu"), Video.Width / 2 - 250, Video.Height - 100,
                  function() menu:stop() end)
-  menu:addButton(_("~!Start"), "s", Video.Width / 2 + 50 ,  Video.Height - 100,
+  menu:addButton(_("~!Start"), Video.Width / 2 + 50 ,  Video.Height - 100,
                  startgamebutton)
 
   menu:run()
