@@ -25,7 +25,6 @@
 --      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 --      02111-1307, USA.
 --
---      $Id: game.lua 8570 2007-02-13 16:47:02Z jim4 $
 
 function BosGameMenu()
   local menu = MenuScreen()
@@ -41,11 +40,11 @@ function BosGameMenu()
   -- FIXME: not a good solution
   -- default size is 200,24 but we want 224,28 so we override these functions
   menu.addButtonOrig = menu.addButton
-  function menu:addButton(caption, hotkey, x, y, callback, size)
-    return self:addButtonOrig(caption, hotkey, x, y, callback, {224, 28})
+  function menu:addButton(caption, x, y, callback, size)
+    return self:addButtonOrig(caption, x, y, callback, {224, 28})
   end
-  function menu:addSmallButton(caption, hotkey, x, y, callback)
-    return self:addButtonOrig(caption, hotkey, x, y, callback, {100, 24})
+  function menu:addSmallButton(caption, x, y, callback)
+    return self:addButtonOrig(caption, x, y, callback, {100, 24})
   end
 
   return menu
@@ -56,20 +55,20 @@ function RunGameMenu(s)
   local menu = BosGameMenu()
 
   menu:addLabel(_("Game Menu"), 128, 11)
-  local b = menu:addButton(_("Save (~<F11~>)"), "f11", 16, 40,
+  local b = menu:addButton(_("Save (~<F11~>)"), 16, 40,
     function() RunSaveMenu() end)
   if (IsReplayGame() or IsNetworkGame()) then
     b:setEnabled(false)
   end
-  menu:addButton(_("Options (~<F5~>)"), "f5", 16, 40 + (36 * 1),
+  menu:addButton(_("Options (~<F5~>)"), 16, 40 + (36 * 1),
     function() RunGameOptionsMenu() end)
-  menu:addButton(_("Help (~<F1~>)"), "f1", 16, 40 + (36 * 2),
+  menu:addButton(_("Help (~<F1~>)"), 16, 40 + (36 * 2),
     function() RunHelpMenu() end)
-  menu:addButton(_("~!Objectives"), "o", 16, 40 + (36 * 3),
+  menu:addButton(_("~!Objectives"), 16, 40 + (36 * 3),
     function() RunObjectivesMenu() end)
-  menu:addButton(_("~!End Game"), "e", 16, 40 + (36 * 4),
+  menu:addButton(_("~!End Game"), 16, 40 + (36 * 4),
     function() RunEndGameMenu() end)
-  menu:addButton(_("Return to Game (~<Esc~>)"), "escape", 16, 248,
+  menu:addButton(_("Return to Game (~<Esc~>)"), 16, 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -82,13 +81,14 @@ function RunSaveMenu()
 
   local t = menu:addTextInputField("game.sav", 16, 40, 224)
 
-  local browser = menu:addBrowser("~save", ".sav.gz$", 16, 70, 224, 166)
+  local lister = CreateFilteringLister(".sav.gz$", ListFilesInDirectory)
+  local browser = menu:addBrowser("~save", lister, 16, 70, 224, 166)
   local function cb(s)
     t:setText(browser:getSelectedItem())
   end
   browser:setActionCallback(cb)
 
-  menu:addSmallButton(_("Save"), 0, 16, 248,
+  menu:addSmallButton(_("Save"), 16, 248,
     -- FIXME: use a confirm menu if the file exists already
     function()
       local name = t:getText()
@@ -109,7 +109,7 @@ function RunSaveMenu()
       menu:stop()
     end)
 
-  menu:addSmallButton(_("Cancel"), 0, 16 + 12 + 106, 248,
+  menu:addSmallButton(_("Cancel"), 16 + 12 + 106, 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -128,13 +128,13 @@ function RunGameOptionsMenu()
   local menu = BosGameMenu()
 
   menu:addLabel(_("Game Options"), 128, 11)
-  menu:addButton(_("Sound (~<F7~>)"), "f7", 16, 40 + (36 * 0),
+  menu:addButton(_("Sound (~<F7~>)"), 16, 40 + (36 * 0),
     function() RunGameSoundOptionsMenu() end)
-  menu:addButton(_("Game (~<F9~>)"), "f9", 16, 40 + (36 * 1),
+  menu:addButton(_("Game (~<F9~>)"), 16, 40 + (36 * 1),
     function() RunPreferencesMenu() end)
-  menu:addButton(_("~!Diplomacy"), "d", 16, 40 + (36 * 2),
+  menu:addButton(_("~!Diplomacy"), 16, 40 + (36 * 2),
     function() RunDiplomacyMenu() end)
-  menu:addButton(_("Previous (~<Esc~>)"), "escape", 128 - (224 / 2), 248,
+  menu:addButton(_("Previous (~<Esc~>)"), 128 - (224 / 2), 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -177,7 +177,7 @@ function RunPreferencesMenu()
   l:adjustSize()
   menu:add(l, 230 - l:getWidth(), (36 * 4) + 6)
 
-  menu:addSmallButton(_("~!OK"), "o", 128 - (106 / 2), 245,
+  menu:addSmallButton(_("~!OK"), 128 - (106 / 2), 245,
     function()
       preferences.FogOfWar = GetFogOfWar()
       preferences.ShowCommandKey = UI.ButtonPanel.ShowCommandKey
@@ -251,7 +251,7 @@ function RunDiplomacyMenu()
     end
   end
 
-  menu:addSmallButton(_("~!OK"), "o", 75, 384 - 40,
+  menu:addSmallButton(_("~!OK"), 75, 384 - 40,
     function()
       for j=1,table.getn(allied) do
         local i = allied[j].index
@@ -301,7 +301,7 @@ function RunDiplomacyMenu()
       end
       menu:stop()
     end)
-  menu:addSmallButton(_("~!Cancel"), "c", 195, 384 - 40, function() menu:stop() end)
+  menu:addSmallButton(_("~!Cancel"), 195, 384 - 40, function() menu:stop() end)
 
   menu:run(false)
 end
@@ -310,46 +310,46 @@ end
 function RunRestartConfirmMenu()
   RunConfirmTypeMenu(
       _("Are you sure you want to restart the game?"),
-      _("~!Restart Game"), "r", GameRestart)
+      _("~!Restart Game"), GameRestart)
 end
 
 function RunQuitToMenuConfirmMenu()
   RunConfirmTypeMenu(
      _("Are you sure you want to quit to the main menu?"),
-     _("~!Quit to Menu"), "q", GameQuitToMenu)
+     _("~!Quit to Menu"), GameQuitToMenu)
 end
 
 function RunEndGameMenu()
   local menu = BosGameMenu()
 
   menu:addLabel(_("End Game"), 128, 11)
-  local b = menu:addButton(_("~!Restart Game"), "r", 16, 40 + (36 * 0),
+  local b = menu:addButton(_("~!Restart Game"), 16, 40 + (36 * 0),
     RunRestartConfirmMenu)
   if (IsNetworkGame()) then
     b:setEnabled(false)
   end
-  menu:addButton(_("~!Surrender"), "s", 16, 40 + (36 * 1),
+  menu:addButton(_("~!Surrender"), 16, 40 + (36 * 1),
     function() RunConfirmTypeMenu(
       _("Are you sure you want to surrender to your enemies?"),
-      _("~!Surrender"), "s", GameDefeat) end)
-  menu:addButton(_("~!Quit to Menu"), "q", 16, 40 + (36 * 2),
+      _("~!Surrender"), GameDefeat) end)
+  menu:addButton(_("~!Quit to Menu"), 16, 40 + (36 * 2),
     RunQuitToMenuConfirmMenu)
-  menu:addButton(_("E~!xit Bos Wars"), "x", 16, 40 + (36 * 3),
+  menu:addButton(_("E~!xit Bos Wars"), 16, 40 + (36 * 3),
     RunExitConfirmMenu)
-  menu:addButton(_("Previous (~<Esc~>)"), "escape", 16, 248,
+  menu:addButton(_("Previous (~<Esc~>)"), 16, 248,
     function() menu:stop() end)
 
   menu:run(false)
 end
 
-function RunConfirmTypeMenu(boxtext, buttontext, hotkey, stopgametype)
+function RunConfirmTypeMenu(boxtext, buttontext, stopgametype)
   local menu = BosGameMenu()
   local height = 11
 
   height = height + menu:addMultiLineLabel(boxtext, 128, 11):getHeight()
-  menu:addButton(buttontext, hotkey, 16, height + 29,
+  menu:addButton(buttontext, 16, height + 29,
     function() StopGame(stopgametype); menu:stopAll() end)
-  menu:addButton(_("Cancel (~<Esc~>)"), "escape", 16, 248,
+  menu:addButton(_("Cancel (~<Esc~>)"), 16, 248,
     function() menu:stop() end)
   menu:run(false)
 end
@@ -360,9 +360,9 @@ function RunExitConfirmMenu()
 
   height = height + menu:addMultiLineLabel(
     _("Are you sure you want to exit Bos Wars?"), 128, 11):getHeight()
-  menu:addButton(_("E~!xit Program"), "x", 16, height + 29,
+  menu:addButton(_("E~!xit Program"), 16, height + 29,
     function() Exit(0) end)
-  menu:addButton(_("Cancel (~<Esc~>)"), "escape", 16, 248,
+  menu:addButton(_("Cancel (~<Esc~>)"), 16, 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -372,58 +372,61 @@ function RunHelpMenu()
   local menu = BosGameMenu()
 
   menu:addLabel(_("Help Menu"), 128, 11)
-  menu:addButton(_("Keystroke ~!Help"), "h", 16, 40 + (36 * 0),
+  menu:addButton(_("Keystroke ~!Help"), 16, 40 + (36 * 0),
     function() RunKeystrokeHelpMenu() end)
-  menu:addButton(_("Bos Wars ~!Tips"), "t", 16, 40 + (36 * 1),
+  menu:addButton(_("Bos Wars ~!Tips"), 16, 40 + (36 * 1),
     function() RunTipsMenu() end)
-  menu:addButton(_("Previous (~<Esc~>)"), "escape", 128 - (224 / 2), 248,
+  menu:addButton(_("Previous (~<Esc~>)"), 128 - (224 / 2), 248,
     function() menu:stop() end)
 
   menu:run(false)
 end
 
-local keystrokes = {
-  {"Alt-F", "- toggle full screen"},
-  {"Alt-G", "- toggle grab mouse"},
-  {"Ctrl-S", "- mute sound"},
-  {"Ctrl-M", "- mute music"},
-  {"+", "- increase game speed"},
-  {"-", "- decrease game speed"},
-  {"Ctrl-P", "- pause game"},
-  {"PAUSE", "- pause game"},
-  {"PRINT", "- make screen shot"},
-  {"Alt-H", "- help menu"},
-  {"Alt-R", "- restart game"},
-  {"Alt-Q", "- quit to main menu"},
-  {"Alt-X", "- quit game"},
-  {"Alt-B", "- toggle expand map"},
-  {"Alt-M", "- game menu"},
-  {"ENTER", "- write a message"},
-  {"SPACE", "- goto last event"},
-  {"TAB", "- hide/unhide terrain"},
-  {"Ctrl-T", "- track unit"},
-  {"Alt-I", "- find idle peon"},
-  {"Alt-C", "- center on selected unit"},
-  {"Alt-V", "- next view port"},
-  {"Ctrl-V", "- previous view port"},
-  {"^", "- select nothing"},
-  {"#", "- select group"},
-  {"##", "- center on group"},
-  {"Ctrl-#", "- define group"},
-  {"Shift-#", "- add to group"},
-  {"Alt-#", "- add to alternate group"},
-  {"F2-F4", "- recall map position"},
-  {"Shift F2-F4", "- save map postition"},
-  {"F5", "- game options"},
-  {"F7", "- sound options"},
-  {"F8", "- speed options"},
-  {"F9", "- preferences"},
-  {"F10", "- game menu"},
-  {"F11", "- save game"},
-  {"F12", "- load game"},
-}
+function InitKeystrokes(keystrokes)
+  table.insert(keystrokes, {_("Alt-F"), _("- toggle full screen")})
+  table.insert(keystrokes, {_("Alt-G"), _("- toggle grab mouse")})
+  table.insert(keystrokes, {_("Ctrl-S"), _("- mute sound")})
+  table.insert(keystrokes, {_("Ctrl-M"), _("- mute music")})
+  table.insert(keystrokes, {_("+"), _("- increase game speed")})
+  table.insert(keystrokes, {_("-"), _("- decrease game speed")})
+  table.insert(keystrokes, {_("Ctrl-P"), _("- pause game")})
+  table.insert(keystrokes, {_("PAUSE"), _("- pause game")})
+  table.insert(keystrokes, {_("PRINT"), _("- make screen shot")})
+  table.insert(keystrokes, {_("Alt-H"), _("- help menu")})
+  table.insert(keystrokes, {_("Alt-R"), _("- restart game")})
+  table.insert(keystrokes, {_("Alt-Q"), _("- quit to main menu")})
+  table.insert(keystrokes, {_("Alt-X"), _("- quit game")})
+  table.insert(keystrokes, {_("Alt-B"), _("- toggle expand map")})
+  table.insert(keystrokes, {_("Alt-M"), _("- game menu")})
+  table.insert(keystrokes, {_("ENTER"), _("- write a message")})
+  table.insert(keystrokes, {_("SPACE"), _("- goto last event")})
+  table.insert(keystrokes, {_("TAB"), _("- hide/unhide terrain")})
+  table.insert(keystrokes, {_("Ctrl-T"), _("- track unit")})
+  table.insert(keystrokes, {_("Alt-I"), _("- find idle peon")})
+  table.insert(keystrokes, {_("Alt-C"), _("- center on selected unit")})
+  table.insert(keystrokes, {_("Alt-V"), _("- next view port")})
+  table.insert(keystrokes, {_("Ctrl-V"), _("- previous view port")})
+  table.insert(keystrokes, {_("^"), _("- select nothing")})
+  table.insert(keystrokes, {_("#"), _("- select group")})
+  table.insert(keystrokes, {_("##"), _("- center on group")})
+  table.insert(keystrokes, {_("Ctrl-#"), _("- define group")})
+  table.insert(keystrokes, {_("Shift-#"), _("- add to group")})
+  table.insert(keystrokes, {_("Alt-#"), _("- add to alternate group")})
+  table.insert(keystrokes, {_("F2-F4"), _("- recall map position")})
+  table.insert(keystrokes, {_("Shift F2-F4"), _("- save map postition")})
+  table.insert(keystrokes, {_("F5"), _("- game options")})
+  table.insert(keystrokes, {_("F7"), _("- sound options")})
+  table.insert(keystrokes, {_("F8"), _("- speed options")})
+  table.insert(keystrokes, {_("F9"), _("- preferences")})
+  table.insert(keystrokes, {_("F10"), _("- game menu")})
+  table.insert(keystrokes, {_("F11"), _("- save game")})
+  table.insert(keystrokes, {_("F12"), _("- load game")})
+end
 
 function RunKeystrokeHelpMenu()
+  local keystrokes = {}
+  InitKeystrokes(keystrokes)
+
   local menu = BosGameMenu()
   menu:setSize(352, 352)
   menu:setPosition((Video.Width - menu:getWidth()) / 2,
@@ -453,35 +456,38 @@ function RunKeystrokeHelpMenu()
   menu:add(s, 16, 60)
 
   menu:addLabel(_("Keystroke Help Menu"), 352 / 2, 11)
-  menu:addButton(_("Previous (~<Esc~>)"), "escape", (352 / 2) - (224 / 2), 352 - 40,
-    function() menu:stop() end)
+  menu:addButton(_("Previous (~<Esc~>)"), (352 / 2) - (224 / 2), 352 - 40,
+    function() menu:stop()  end)
 
   menu:run(false)
 end
 
-local tips = {
-  "You can select all of your currently visible units of the same type by holding down the CTRL key and selecting a unit or by \"double clicking\" on a unit.",
-  "The more engineers you have collecting resources, the faster your economy will grow.",
+function InitTips(tips)
+  table.insert(tips, _("You can select all of your currently visible units of the same type by holding down the CTRL key and selecting a unit or by \"double clicking\" on a unit."))
+  table.insert(tips, _("The more engineers you have collecting resources, the faster your economy will grow."))
 
-  "Use your engineers to repair damaged buildings.",
-  "Explore your surroundings early in the game.",
+  table.insert(tips, _("Use your engineers to repair damaged buildings."))
+  table.insert(tips, _("Explore your surroundings early in the game."))
 
 
-  "Keep all engineers working. Use ALT-I to find idle engineers.",
-  "You can make units automatically cast spells by selecting a unit, holding down CTRL and clicking on the spell icon.  CTRL click again to turn off.",
+  table.insert(tips, _("Keep all engineers working. Use ALT-I to find idle engineers."))
+  table.insert(tips, _("You can make units automatically perform special actions by selecting a unit, holding down CTRL and clicking on the icon.  CTRL click again to turn off."))
 
   -- Shift tips
-  "You can give an unit an order which is executed after it finishes the current work, if you hold the SHIFT key.",
-  "You can give way points, if you press the SHIFT key, while you click right for the move command.",
-  "You can order an engineer to build one building after the other, if you hold the SHIFT key, while you place the building.",
-  "You can build many of the same building, if you hold the ALT and SHIFT keys while you place the buildings.",
+  table.insert(tips, _("You can give an unit an order which is executed after it finishes the current work, if you hold the SHIFT key."))
+  table.insert(tips, _("You can give way points, if you press the SHIFT key, while you click right for the move command."))
+  table.insert(tips, _("You can order an engineer to build one building after the other, if you hold the SHIFT key, while you place the building."))
+  table.insert(tips, _("You can build many of the same building, if you hold the ALT and SHIFT keys while you place the buildings."))
 
-  "Use CTRL-V or ALT-V to cycle through the viewport configuration, you can than monitor your base and lead an attack.",
+  table.insert(tips, _("Use CTRL-V or ALT-V to cycle through the viewport configuration, you can than monitor your base and lead an attack."))
 
-  "Know a useful tip?  Then add it here!",
-}
+  table.insert(tips, _("Know a useful tip?  Then add it here!"))
+end
 
 function RunTipsMenu()
+  local tips = {}
+  InitTips(tips)
+
   local menu = BosGameMenu()
   menu:setSize(384, 256)
   menu:setPosition((Video.Width - menu:getWidth()) / 2,
@@ -524,11 +530,11 @@ function RunTipsMenu()
       SavePreferences()
     end)
   showtips:setMarked(preferences.ShowTips)
-  menu:addSmallButton(_("~!OK"), "o", 14, 256 - 40,
+  menu:addSmallButton(_("~!OK"), 14, 256 - 40,
     function() l:nextTip(); menu:stop() end)
-  menu:addSmallButton(_("~!Previous Tip"), "p", 14 + 106 + 11, 256 - 40,
+  menu:addSmallButton(_("~!Previous Tip"), 14 + 106 + 11, 256 - 40,
     function() l:prevTip(); l:updateCaption() end)
-  menu:addSmallButton(_("~!Next Tip"), "n", 14 + 106 + 11 + 106 + 11, 256 - 40,
+  menu:addSmallButton(_("~!Next Tip"), 14 + 106 + 11 + 106 + 11, 256 - 40,
     function() l:nextTip(); l:updateCaption() end)
 
   menu:run(false)
@@ -548,9 +554,9 @@ function RunObjectivesMenu()
   l:setLineWidth(356)
   menu:add(l, 14, 36)
 
-  l:setCaption(current_objective)
+  l:setCaption(GetObjectives())
 
-  menu:addButton(_("~!OK"), "o", 80, 256 - 40,
+  menu:addButton(_("~!OK"), 80, 256 - 40,
     function() menu:stop() end)
 
   menu:run(false)
