@@ -9,7 +9,7 @@
 --
 --      uilayout.lua - Define the ingame layout and user interface
 --
---      (c) Copyright 2001-2006 by Lutz Sammer, Jimmy Salmon, Crestez Leonard,
+--      (c) Copyright 2001-2007 by Lutz Sammer, Jimmy Salmon, Crestez Leonard,
 --                                 and Francois Beerten.
 --
 --      This program is free software; you can redistribute it and/or modify
@@ -26,39 +26,11 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---      $Id: uilayout.lua 8961 2007-06-30 19:50:01Z jim4 $
 
 
 function DefineElitePanels(info_panel_x, info_panel_y) 
-   local min_damage = Max(1, Div(ActiveUnitVar("PiercingDamage"), 2))
-   local max_damage = Add(ActiveUnitVar("PiercingDamage"), ActiveUnitVar("BasicDamage"))
-   local damage_bonus = Sub(ActiveUnitVar("PiercingDamage", "Value", "Type"),
-                            ActiveUnitVar("PiercingDamage", "Value", "Initial"))
-
    DefinePanelContents(
 -- Default presentation. ------------------------
-  {
-  Ident = "panel-general-contents",
-  Pos = {info_panel_x, info_panel_y}, DefaultFont = "game",
-  Contents = {
-	{ Pos = {14, 56}, Condition = {ShowOpponent = false, HideNeutral = true},
-		More = {"LifeBar", {Variable = "HitPoints", Height = 7, Width = 45}}
-	},
-	{ Pos = {38, 62}, Condition = {ShowOpponent = false, HideNeutral = true},
-		More = {"FormattedText2", {
-			Font = "small", Variable = "HitPoints", Format = "%d/%d",
-			Component1 = "Value", Component2 = "Max", Centered = true}}
-	},
-	{ Pos = {114, 25}, More = {"Text", {ShowName = true}} }, -- FIXME:split for long name
-	--{ Pos = {10, 158}, More = {"Text", {Variable = "Slot"}},
-	--	Condition = {Slot = "only"} }, -- DEBUG ONLY.
--- Resource Left
-	{ Pos = {76, 86}, Condition = {ShowOpponent = false, GiveResource = "only"},
-		More = {"FormattedText2", {Format = "%s: %d", Variable = "GiveResource",
-					Component1 = "Name", Component2 = "Value", Centered = true}}
-	}
-
-  } },
 -- All own unit -----------------
   {
   Ident = "panel-all-unit-contents",
@@ -66,17 +38,6 @@ function DefineElitePanels(info_panel_x, info_panel_y)
   DefaultFont = "game",
   Condition = {ShowOpponent = false, HideNeutral = true, Build = "false"},
   Contents = {
-         { Pos = {16, 138}, Condition = {BasicDamage = "only"},
-            More = {"Text", {Text = Concat("Damage: ", String(min_damage), 
-                                           "-", String(max_damage),
-                                           If(Equal(0, damage_bonus), "",
-                                              InverseVideo(Concat("+", String(damage_bonus)))) 
-                                          )}}
-        },
-	{ Pos = {16, 111}, Condition = {AttackRange = "only"},
-		More = {"Text", {
-			 Text = "Range: ", Variable = "AttackRange" , Stat = true}}
-	},
 -- Construction
 	{ Pos = {12, 153}, Condition = {Build = "only"},
 		More = {"CompleteBar", {Variable = "Build", Width = 152, Height = 12}}
@@ -94,36 +55,12 @@ function DefineElitePanels(info_panel_x, info_panel_y)
 	},
 	{ Pos = {86, 141}, More = {"Text", {Variable = "Mana"}}, Condition = {Mana = "only"} },
 
-  } },
--- Attack Unit -----------------------------
-  {
-  Ident = "panel-attack-unit-contents",
-  Pos = {info_panel_x, info_panel_y},
-  DefaultFont = "game",
-  Condition = {ShowOpponent = false, HideNeutral = true, Building = "false", Build = "false"},
-  Contents = {
--- Unit caracteristics
-	{ Pos = {114, 37},
-		More = {"FormattedText", {Centered = true, 
-			Variable = "Level", Format = "Level ~<%d~>"}}
-	},
-	{ Pos = {114, 52},
-		More = {"FormattedText", {Centered = true,
-			Variable = "Kill", Format = "Kills:~<%d~>"}}
-	},
-	{ Pos = {16, 84}, Condition = {Armor = "only"},
-		More = {"Text", {Text = "Armor: ", Variable = "Armor", Stat = true}}
-	},
-	{ Pos = {16, 125}, Condition = {SightRange = "only"},
-		More = {"Text", {Text = "Sight: ", Variable = "SightRange", Stat = true}}
-	},
-	{ Pos = {16, 97}, Condition = {Speed = "only"},
-		More = {"Text", {Text = "Speed: ", Variable = "Speed", Stat = true}}
-	} } })
+  } }
+  )
 end
 
 
-DefineElitePanels(Video.Width - 200, 152)
+--DefineElitePanels(Video.Width - 200, 152)
 
 
 UI.NormalFontColor = "light-blue"
@@ -139,7 +76,7 @@ function AddFiller(file, x, y)
 end
 
 UI.Fillers:clear()
-AddFiller("elites/ui/ui_minimap.png", Video.Width - 200, 24 - 8)
+AddFiller("graphics/ui/ui_minimap.png", Video.Width - 200, 24 - 8)
 if (Editor.Running == EditorNotRunning) then
   local w = Video.Width
   -- FIXME: remove this when we have images for these resolutions
@@ -148,12 +85,12 @@ if (Editor.Running == EditorNotRunning) then
   elseif (w == 1280) then
     w = 1024
   end
-  AddFiller("elites/ui/ui_" .. w .. "_bpanel.png",
+  AddFiller("graphics/ui/ui_" .. w .. "_bpanel.png",
     Video.Width - 200, 336 - 8 - 8)
 end
 
 b = CFiller:new_local()
-b.G = CGraphic:New("elites/ui/ui_info.png", 200, 176)
+b.G = CGraphic:New("graphics/ui/ui_info.png", 200, 176)
 b.X = Video.Width - 200
 b.Y = 152
 UI.Fillers:push_back(b)
@@ -262,6 +199,9 @@ UI.MapArea.ScrollPaddingRight = 0
 UI.MapArea.ScrollPaddingTop = 0
 UI.MapArea.ScrollPaddingBottom = 0
 
+UI.MessageFont = Fonts["game"]
+UI.MessageScrollSpeed = 5
+
 UI.Minimap.X = Video.Width - 200 + 46
 UI.Minimap.Y = 24 + 17 - 8
 UI.Minimap.W = 121
@@ -277,7 +217,7 @@ UI.Timer.Y = UI.MapArea.Y + 15
 UI.Timer.Font = Fonts["game"]
 
 -- energy
-UI.Resources[0].G = CGraphic:New("elites/ui/ui_res_icons.png", 14, 14)
+UI.Resources[0].G = CGraphic:New("graphics/ui/ui_res_icons.png", 14, 14)
 UI.Resources[0].IconFrame = 0
 UI.Resources[0].IconX = 67 + 0
 UI.Resources[0].IconY = 0
@@ -285,21 +225,13 @@ UI.Resources[0].TextX = 85 + 0
 UI.Resources[0].TextY = 1
 
 -- magma
-UI.Resources[1].G = CGraphic:New("elites/ui/ui_res_icons.png", 14, 14)
+UI.Resources[1].G = CGraphic:New("graphics/ui/ui_res_icons.png", 14, 14)
 UI.Resources[1].IconFrame = 1
 UI.Resources[1].IconX = 67 + 75
 UI.Resources[1].IconY = 0
 UI.Resources[1].TextX = 85 + 75
 UI.Resources[1].TextY = 1
 
--- score
-UI.Resources[ScoreCost].G = CGraphic:New("elites/ui/ui_res_icons.png", 14, 14)
-UI.Resources[ScoreCost].IconFrame = 4
-UI.Resources[ScoreCost].IconX = 67 + 250
-UI.Resources[ScoreCost].IconY = 0
-UI.Resources[ScoreCost].TextX = 85 + 250
-UI.Resources[ScoreCost].TextY = 1
-
 UI.PieMenu.G = CGraphic:New("ui/rosace1.png")
 UI.PieMenu.MouseButton = MiddleButton
 UI.PieMenu:SetRadius(70)
