@@ -26,7 +26,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: units.lua 8861 2007-06-07 06:24:18Z jim4 $
 
 -- Load the animations for the units.
 Load("scripts/anim.lua")
@@ -62,21 +61,21 @@ end
 function DefineCommonButtons(forUnits) 
    DefineButton({
         Pos = 1, Level = 0, Icon = "icon-move",
-        Action = "move", Key = "m", Hint = "~!MOVE",
+        Action = "move", Hint = "~!MOVE",
         ForUnit = forUnits})
    DefineButton({
         Pos = 2, Level = 0, Icon = "icon-stop",
-        Action = "stop", Key = "s", Hint = "~!STOP",
+        Action = "stop", Hint = "~!STOP",
         ForUnit = forUnits})
    DefineButton({
         Pos = 3, Level = 0, Icon = "icon-attack",
-        Action = "attack", Key = "a", Hint = "~!ATTACK", ForUnit = forUnits})
+        Action = "attack", Hint = "~!ATTACK", ForUnit = forUnits})
    DefineButton({
         Pos = 4, Level = 0, Icon = "icon-patrol",
-        Action = "patrol", Key = "p", Hint = "~!PATROL", ForUnit = forUnits})
+        Action = "patrol", Hint = "~!PATROL", ForUnit = forUnits})
    DefineButton({
         Pos = 5, Level = 0, Icon = "icon-stand-ground",
-        Action = "stand-ground", Key = "t", Hint = "S~!TAND GROUND", 
+        Action = "stand-ground", Hint = "S~!TAND GROUND", 
         ForUnit = forUnits})
 end
 
@@ -86,15 +85,18 @@ DefineAnimations("animations-elitecorpse1", {
         "frame 15", "wait 200", "frame 15", "wait 1", "unbreakable end", "wait 1", },
     })
 
-function DefineHumanCorpse(livingunit, size)
-   if (size == nil) then
+function DefineHumanCorpse(livingunit, size, flip)
+  if (size == nil) then
     size = {64, 64}
-   end
+  end
+  if (flip == nil) then
+    flip = false
+  end
 
-   DefineUnitType("unit-dead-" .. livingunit, {
+  DefineUnitType("unit-dead-" .. livingunit, {
 	Name = livingunit .. "body",
 	Image = {"file", GetCurrentLuaPath().."/unit_" .. livingunit .. "_c.png", "size", size},
-	Animations = "animations-elitecorpse1", Icon = "icon-cancel",
+	Animations = "animations-elitecorpse1", Icon = "icon-cancel", Flip = flip,
 	Speed = 0, HitPoints = 999, DrawLevel = 10, TileSize = {1, 1},
 	BoxSize = {31, 31}, SightRange = 1, BasicDamage = 0,
 	PiercingDamage = 0, Missile = "missile-none",
@@ -105,7 +107,7 @@ end
 DefineUnitType("unit-dead-body", {
 	Name= "Dead Body",
 	Image = {"file", "neutral/units/corpses.png", "size", {72, 72}},
-	Animations = "animations-dead-body", Icon = "icon-cancel",
+	Animations = "animations-dead-body", Icon = "icon-cancel", Flip = true,
 	Speed = 0, HitPoints = 255, DrawLevel = 30, Priority = 0,
 	TileSize = {1, 1}, BoxSize = {31, 31}, SightRange = 1,
 	BasicDamage = 0, PiercingDamage = 0, Missile = "missile-none",
