@@ -25,7 +25,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: unit-cannon.lua 8831 2007-05-28 20:06:45Z feb $
 
 DefineAnimations("animations-cannon", {
     Still = {"frame 5", "wait 1", },
@@ -107,12 +106,12 @@ DefineUnitType("unit-cannon", {
     CanTargetLand = true,
     CanTargetAir = false,
     NumDirections = 8,
-    Flip = false,
     Corpse = "build-dead-cannon",
     Type = "land",
     Building = true,
     BuilderOutside = true,
     VisibleUnderFog = true,
+    CanHarvestFrom = true,
     Sounds = {
         "selected", "cannon-selected",
         "help", "cannon-help",
@@ -151,7 +150,7 @@ DefineAllow("unit-cannon", AllowAll)
 
 DefineButton({
     Pos = 3, Level = 3, Icon = "icon-cannon_b", Action = "build",
-    Value = "unit-cannon", Key = "c", Hint = "BUILD ~!CANNON",
+    Value = "unit-cannon", Hint = "BUILD ~!CANNON",
     ForUnit = {"unit-engineer"}})
 -- DefineButton for the 'stop' and 'attack' actions are defined in buttons.lua.
 
