@@ -25,7 +25,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: unit-dorcoz.lua 8947 2007-06-28 17:57:13Z feb $
 
 DefineAnimations("animations-dorcoz", {
     Still = {"frame 0", "wait 1", },
@@ -49,7 +48,7 @@ DefineIcon({
 
 DefineMissileType("missile-dorcoz", {
         File = "units/dorcoz/mis_plasma_sml.png",
-        Size = {32, 32}, Frames = 5, NumDirections = 5,
+        Size = {32, 32}, Frames = 5, NumDirections = 8,
         DrawLevel = 50,
         Class = "missile-class-point-to-point", Sleep = 1, Speed = 32, Range = 1})
 
@@ -58,6 +57,7 @@ DefineUnitType("unit-dorcoz", {
     Image = {"file", "units/dorcoz/unit_dorcoz.png", "size", {64, 64}},
     Animations = "animations-dorcoz",
     Icon = "icon-dorcoz",
+    Flip = true,
     EnergyValue = 4500,
     MagmaValue = 2500,
     Speed = 10,
@@ -82,7 +82,7 @@ DefineUnitType("unit-dorcoz", {
     CanTargetLand = true,
     CanTargetAir = true,
     LandUnit = true,
-    organic = true,
+    Organic = true,
     SelectableByRectangle = true,
     RightMouseAction = "attack"
 })
@@ -92,6 +92,6 @@ DefineAllow("unit-dorcoz", AllowAll)
 DefineButton({
         Pos = 4, Level = 0, Icon = "icon-dorcoz",
         Action = "train-unit", Value = "unit-dorcoz",
-        Key = "d", Hint = "TRAIN ~!DORCOZ",
+        Hint = "TRAIN ~!DORCOZ",
         ForUnit = {"unit-camp"}})
 
