@@ -9,7 +9,7 @@
 --
 --	unit-gturret.lua	-	Define the gun turret unit.
 --
---	(c) Copyright 2004-2005 by Franois Beerten.
+--	(c) Copyright 2004-2007 by Franois Beerten.
 --
 --      This program is free software; you can redistribute it and/or modify
 --      it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: unit-gturret.lua 8831 2007-05-28 20:06:45Z feb $
 
 DefineAnimations("animations-gturret", {
     Still = {"frame 5", "wait 1", },
@@ -93,12 +92,12 @@ DefineUnitType("unit-gturret", {
     CanTargetLand = true,
     CanTargetAir = true,
     NumDirections = 8,
-    Flip = false,
     Corpse = "build-dead-gturret",
     Type = "land",
     Building = true,
     BuilderOutside = true,
     VisibleUnderFog = true,
+    CanHarvestFrom = true,
     Sounds = {
         "selected", "gturret-selected",
         "ready", "gturret-ready",
@@ -142,7 +141,7 @@ DefineAllow("unit-gturret", AllowAll)
 
 DefineButton({
     Pos = 2, Level = 3, Icon = "icon-gturret_b", Action = "build",
-    Value = "unit-gturret", Key = "g", Hint = "BUILD ~!GUN TURRET",
+    Value = "unit-gturret", Hint = "BUILD ~!GUN TURRET",
     ForUnit = {"unit-engineer"}})
 -- DefineButton for the 'stop' and 'attack' actions are defined in buttons.lua.
 
